@@ -11,6 +11,8 @@ from baangt.TestCase.TestCaseMaster import TestCaseMaster
 from baangt.TestCaseSequence.TestCaseSequenceMaster import TestCaseSequenceMaster
 from baangt.base.ProxyRotate import ProxyRotate
 from baangt.base.FilesOpen import FilesOpen
+import xlsxwriter
+import os
 import json
 import logging
 from pathlib import Path
@@ -22,6 +24,9 @@ import time
 from baangt.base.PathManagement import ManagedPaths
 from uuid import uuid4
 from baangt.base.RuntimeStatistics import Statistic
+from baangt.base.SendReports import Sender
+import signal
+from baangt.TestDataGenerator.TestDataGenerator import TestDataGenerator
 
 logger = logging.getLogger("pyC")
 
@@ -56,6 +61,7 @@ class TestRun:
         self.kwargs = {}
         self.dataRecords = {}
         self.globalSettings = {}
+        self.json_dict = {} # Used to maintain records of RLP_ data which will be used will exporting results
         self.managedPaths = ManagedPaths()
         self.classesForObjects = ClassesForObjects()         # Dynamically loaded classes
         self.timing = Timing()
@@ -67,6 +73,8 @@ class TestRun:
         # from anywhere within your custom code base.
         self.additionalExportTabs = {}
         self.statistics = Statistic()
+        signal.signal(signal.SIGINT, self.exit_signal_handler)
+        signal.signal(signal.SIGTERM, self.exit_signal_handler)
 
         # Initialize other values
         self.timing.takeTime(GC.TIMING_TESTRUN)               # Initialize Testrun Duration
@@ -76,6 +84,9 @@ class TestRun:
         if executeDirect:
             self.executeTestRun()
 
+    def exit_signal_handler(self, signal, frame):
+        self.browserFactory.teardown()
+
     def executeTestRun(self):
         self._initTestRunSettingsFromFile()  # Loads the globals*.json file
 
@@ -83,10 +94,14 @@ class TestRun:
         self._loadExcelTestRunDefinitions()
 
         self.browserFactory = BrowserFactory(self)
-
         self.executeTestSequence()
         self.tearDown()
 
+        try:
+            Sender.send_all(self.results, self.globalSettings)
+        except Exception as ex:
+            logger.error(f"Error from SendAll: {ex}")
+
     def append1DTestCaseEndDateTimes(self, dt):
         self.testCasesEndDateTimes_1D.append(dt)
 
@@ -262,9 +277,6 @@ class TestRun:
                 # Damn! The class is wrong.
                 l_class = TestRun.__dynamicImportClasses(lFullQualified)
                 l_class(**kwargs)
-            success, error = self.getSuccessAndError()
-            waiting = self.getWaiting()
-            self.statistics.update_all(success, error, waiting)
 
         self.kwargs = kwargs
 
@@ -311,13 +323,17 @@ class TestRun:
             if isinstance(value, str):
                 if value.lower() in ("false", "true", "no", "x"):
                     self.globalSettings[key] = utils.anything2Boolean(value)
-
+                elif "renv_" in value.lower():
+                    self.globalSettings[key] = TestDataGenerator.get_env_variable(value[5:])
             if isinstance(value, dict):
                 if "default" in value:
                     # This happens in the new UI, if a value was added manually,
                     # but is not part of the globalSetting.json. In this case there's the whole shebang in a dict. We
                     # are only interested in the actual value, which is stored in "default":
                     self.globalSettings[key] = value["default"]
+                    if isinstance(self.globalSettings[key], str):
+                        if "renv_" in self.globalSettings[key].lower():
+                            self.globalSettings[key] = TestDataGenerator.get_env_variable(self.globalSettings[key][5:])
                     continue
                 else:
                     # This could be the "old" way of the globals-file (with {"HEADLESS":"True"})
